<?php
/*
//

File:				registry.class.php
Objective:			An ultra simple registry to remove objects from the global namespace
//
*/

/**
* @package  OpenBASE
* @author   Padraic Brady <maugrimtr@hotmail.com>
*
* Registry is a simple object registry class, using the singleton pattern, to allow access to non-static methods by
* other classes, but without placing those object within the global namespace
*
* Usage:
*
* to register an object:
*
* $registry = &Registry::instance();
* $newobj = new Object();
* $registry->setEntry('key', $newobj); // 'key' must be passed back to getEntry() to retrieve the object
*
* to reference a registered object from within another class
*
* $register =& Register::instance();
* $ref_obj =& $register->getEntry('objname'); // the text of the object variable name
*
*/

class Registry {

	/**
    * An array of objects as entered using setEntry()
    *
    * @access   private
    * @var      array
    */
    var $_cache;

	/**
    * Constructor, initialises $_cache
    *
    * @param    none
    * @return   none
    * @access   private
	* @see		$_cache
    * @author	Padraic Brady <maugrimtr@hotmail.com>
    */
    function Registry() {
        $this->_cache = array();
    }

	/**
    * Within $_cache array, sets the passed by reference object as value to the $key key
    *
    *
    * @param    string
	* @param	object
    * @return   none
    * @access   public
	* @see		$_cache
    * @author   Padraic Brady <maugrimtr@hotmail.com>
    */
    function setEntry($key, &$item) {
        $this->_cache[$key] = &$item;
    }

	/**
    * returns the object matching $key
    *
    *
    * @param    string
    * @return   object or null if not an entry referenced by the passed key
    * @access   public
	* @see		$_cache
    * @author   Padraic Brady <maugrimtr@hotmail.com>
    */
    function &getEntry($key) {
        return $this->_cache[$key];
    }

	/**
    * Checks if an object is already an entry, returns true/false as result
    *
    *
    * @param    string
    * @return   boolean true, if entry exists
    * @access   public
    * @author   Padraic Brady <maugrimtr@hotmail.com>
    */
    function isEntry($key) {
        return ($this->getEntry($key) !== null);
    }

	/**
    * Creates a new instance of Registry, or if already held, returns value of static $registry
    *
	* Where the magic happens, the php4 reference need some thinking, but many will recognise the singleton
	* pattern utilised here. When called statically from within other classes, it will return a new instance of
	* Registry, or the current instance held by the static $registry. Overall, it's not a huge improvement over
	* referencing through $GLOBALS, but it is better than prior practice...
    *
    * @param    none
    * @return   object	referenced instance of Registry
    * @access   public
	* @static
    * @author   Padraic Brady <maugrimtr@hotmail.com>
    */
    function &instance() {
        static $registry;
        if (!$registry) {
            $registry = new Registry();
        }
        return $registry;
    }
}

?>